@@ -16,6 +16,8 @@
       INTEGER   IPT(MAXNT)
       REAL      TL1(MAXNT),TL2(MAXNT)
 
+      REAL      TXM,TXX,TYM,TYX,TUX,TUY
+
       EXTERNAL  IUETON, IUWGX, IUWGY
 
       CALL SGIGET('IBGCLI',IBGCLI)
@@ -70,13 +72,26 @@
       IWIDTH = IXMAX-IXMIN+1
       IHIGHT = IYMAX-IYMIN+1
 
-      CALL SWIOPN(IXMIN, IYMIN, IWIDTH, IHIGHT, 
+      CALL SWIOPN(IXMIN, IYMIN, IWIDTH, IHIGHT,
      +            WX1, WY1, WX2, WY2, WX3, WY3, WX4, WY4)
 
 *     / LOOP FOR EACH PIXEL /
+        CALL SGQTRN(ITR)
+        CALL SGQTXY(TXM,TXX,TYM,TYX)
+ 362    IF (TXM.LT.-180.) TXM=TXM+360.
+        IF (TXM.GT.180.) TXM=TXM-360.
+        IF ((TXM.LT.-180.).OR.(TXM.GT.180.)) GOTO 362
+ 363    IF (TXX.LT.-180.) TXX=TXX+360.
+        IF (TXX.GT.180.) TXX=TXX-360.
+        IF ((TXX.LT.180.).OR.(TXX.GT.180.)) GOTO 363
+ 365    IF (TYM.LT.-90.) TYM=TYM+180.
+        IF (TYM.GT.90.) TYM=TYM-180.
+        IF ((TYM.LT.-90.).OR.(TYM.GT.90.)) GOTO 365
+ 366    IF (TYX.LT.-90.) TYX=TYX+180.
+        IF (TYX.GT.90.) TYX=TYX-180.
+        IF ((TYX.LT.-90.).OR.(TYX.GT.90.)) GOTO 366
 
       DO 30 J=1, IHIGHT
-
         DO 20 I=1, IWIDTH
 
           CALL SWIINT(I+IXMIN-1, J+IYMIN-1, WX, WY)
@@ -89,12 +104,25 @@
             CALL STITRF(VX, VY, UX, UY)
           END IF
 
+        TUX=UX
+        TUY=UY
+ 361    IF (TUX.LT.-180.) TUX=TUX+360.
+        IF (TUX.GT.180.) TUX=TUX-360.
+        IF ((TUX.LT.-180.).OR.(TUX.GT.180.)) GOTO 361
+ 364    IF (TUY.LT.-90.) TUY=TUY+180.
+        IF (TUY.GT.90.) TUY=TUY-180.
+        IF ((TUY.LT.-90.).OR.(TUY.GT.90.)) GOTO 364
+
           IF (UX.EQ.RUNDEF) THEN
             IMAGE(I) = 0
           ELSE
             IX = IUWGX(UX)
             IY = IUWGY(UY)
-            IF (IX.EQ.IUNDEF .OR. IY.EQ.IUNDEF) THEN
+            IF (((TUX.LT.TXM).OR.(TUX.GT.TXX).OR.
+     +          (TUY.LT.TYM).OR.(TUY.GT.TYX))
+     +          .AND.(ITR.GE.5))THEN
+              IMAGE(I) = 0
+            ELSE IF (IX.EQ.IUNDEF .OR. IY.EQ.IUNDEF) THEN
               IMAGE(I) = 0
             ELSE
               ZZ = Z(IX, IY)
